@@ -13,7 +13,7 @@
 #' Brandon Whitcher \email{bwhitcher@@gmail.com}
 #' @references
 #' ANALYZE 7.5\cr
-#' \url{https://rportal.mayo.edu/bir/ANALYZE75.pdf}\cr
+#' \url{http://eeg.sourceforge.net/ANALYZE75.pdf}\cr
 #' NIfTI-1\cr
 #' \url{http://nifti.nimh.nih.gov/}
 #'
@@ -22,11 +22,11 @@ setGeneric("dim_un0", function(object) standardGeneric("dim_un0"))
 #' @rdname dim_un0-methods
 #' @aliases dim_un0,anlz-method
 #' @export
-setMethod("dim_un0", "anlz", function(object) { object@"dim_un0" })
+setMethod("dim_un0", "anlz", function(object) object@"dim_un0")
 #' @rdname dim_un0-methods
 #' @aliases dim_un0<- 
 #' @export
-setGeneric("dim_un0<-", function(object, value) { standardGeneric("dim_un0<-") })
+setGeneric("dim_un0<-", function(object, value) standardGeneric("dim_un0<-"))
 #' @rdname dim_un0-methods
 #' @aliases dim_un0<-,anlz-method
 #' @export
