@@ -13,7 +13,7 @@
 #' Brandon Whitcher \email{bwhitcher@@gmail.com}
 #' @references
 #' ANALYZE 7.5\cr
-#' \url{https://rportal.mayo.edu/bir/ANALYZE75.pdf}\cr
+#' \url{http://eeg.sourceforge.net/ANALYZE75.pdf}\cr
 #' NIfTI-1\cr
 #' \url{http://nifti.nimh.nih.gov/}
 #'
@@ -22,11 +22,11 @@ setGeneric("omin", function(object) standardGeneric("omin"))
 #' @rdname omin-methods
 #' @aliases omin,anlz-method
 #' @export
-setMethod("omin", "anlz", function(object) { object@"omin" })
+setMethod("omin", "anlz", function(object) object@"omin")
 #' @rdname omin-methods
 #' @aliases omin<- 
 #' @export
-setGeneric("omin<-", function(object, value) { standardGeneric("omin<-") })
+setGeneric("omin<-", function(object, value) standardGeneric("omin<-"))
 #' @rdname omin-methods
 #' @aliases omin<-,anlz-method
 #' @export
